/**
 * $Header: D:/Projects/Repository/GaugeAPI/edu/cmu/cs/able/gaugeInfrastructure/RMI/RMIGaugeConsumerHandleImp.java,v 1.4 2002/01/31 16:39:04 schmerl Exp $
 * $Log: RMIGaugeConsumerHandleImp.java,v $
 * Revision 1.4  2002/01/31 16:39:04  schmerl
 * Added CVS header information
 *
 */

package edu.cmu.cs.able.gaugeInfrastructure.RMI;

import java.util.Vector;
import java.util.Enumeration;

import java.rmi.*;

import edu.cmu.cs.able.gaugeInfrastructure.*;
import edu.cmu.cs.able.gaugeInfrastructure.util.*;
import edu.cmu.cs.able.gaugeInfrastructure.Events.*;
/**
 * RMIGaugeConsumerHandleImp is a proxy gauge consumer that acts as if it is the actual
 * gauge consumer it refers to. It is used to hide the details of how to maintain
 * the peer-to-peer interaction between a local caller (or client) and a remote
 * callee (or server).
 * @author      Hong Yan
 * @author      Bradley Schmerl
 * @version     1.0
 * @since       JDK1.3.1
 */
public class RMIGaugeConsumerHandleImp extends java.rmi.server.UnicastRemoteObject implements RMIGaugeConsumerHandle, java.io.Serializable
{
    private StringObjectVector gaugeMgrHandleList;
    
    private RMIGaugeConsumer gaugeConsumer;
    
    private RMIGaugeReportingBus gaugeBus;  

    /**
    * Constructor of RMIGaugeConsumerHandleImp
    * @param gaugeConsumer The gauge consumer this handle refers to
    */
    public RMIGaugeConsumerHandleImp(RMIGaugeConsumer gaugeConsumer) throws java.rmi.RemoteException
    {
        super();
        this.gaugeConsumer = gaugeConsumer;
        gaugeMgrHandleList = new StringObjectVector();      
        try {
            gaugeBus = new RMIGaugeReportingBus (gaugeConsumer.busHost);                    
        }
        catch (Exception e) {}
    }

    /** 
    * Configures a gauge.
    * @param theGaugeID The GaugeID of the gauge being configured
    * @param configParams   the configuration parameters
    */
    public void configureGauge(GaugeID theGaugeID, StringPairVector configParams)
    {   
        for (int i = 0; i < gaugeMgrHandleList.size(); i++) {
            RMIGaugeMgrHandle gmh = (RMIGaugeMgrHandle)(gaugeMgrHandleList.valueAt(i));
            try {
                gmh.configureGauge(theGaugeID, configParams);
            }
            catch (RemoteException re) {
                re.printStackTrace();
            }
        }
    }

    /** 
    * Deletes a gauge.
    * @param theGaugeID The GaugeID of the gauge being deleted
    */
    public void deleteGauge(GaugeID theGaugeID)
    {   
        for (int i = 0; i < gaugeMgrHandleList.size(); i++) {
            RMIGaugeMgrHandle gmh = (RMIGaugeMgrHandle)(gaugeMgrHandleList.valueAt(i));
            try {
                gmh.deleteGauge(new RMIGauge(theGaugeID));
            }
            catch (RemoteException re) {
                re.printStackTrace();
            }
        }
    }
    
    public void addGauge(GaugeID theGaugeID, StringPairVector configParams, StringPairVector setupParams) throws java.rmi.RemoteException
    {
        System.out.println("gauge added to gui"+configParams.toString()+setupParams.toString());
        RMIGauge gauge = new RMIGauge(theGaugeID);
        gauge.configParams = configParams;
        gauge.setupParams = setupParams;
        gaugeConsumer.onReportCreated(gauge);
    }
    
    public void addGauge(GaugeID theGaugeID) throws java.rmi.RemoteException
    {
        RMIGauge gauge = new RMIGauge(theGaugeID);
        gaugeConsumer.onReportCreated(gauge);
    }
    
    /** Returns the UID of this gauge consumer.
     * @return
     */    
     public String getGaugeConsumerUID() throws java.rmi.RemoteException
    {
        return gaugeConsumer.gaugeConsumerUID;
    }

    public java.rmi.Remote connectTo(String host, String service) {
        try {
            /*System.setSecurityManager (new RMISecurityManager() {
                public void checkConnect (String host, int port) {}
                public void checkConnect (String host, int port, Object context) {}
            });*/
            if (service.equals("Gauge")) {
                System.out.println("trying to "+"rmi://"+host+"/"+service);
                RMIGaugeHandleInt gh = (RMIGaugeHandleInt)Naming.lookup("rmi://"+host+"/"+service);
                return gh;
            } else {
                System.out.println("trying to "+"rmi://"+host+"/"+service);
                RMIGaugeMgrHandle gmh = (RMIGaugeMgrHandle)Naming.lookup("rmi://"+host+"/"+service);
                gaugeMgrHandleList.addElement(gmh.getGaugeMgrUID(), gmh);
                return gmh;
            }               
        }
        catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    /** Called when a value is reported
     * @param gauge The GaugeID of the gauge reporting the value
     */    
    public void onReportValue(GaugeID gauge, String valueName, String propertyName, String value) throws java.rmi.RemoteException
    {
        String host = gaugeBus.getGaugeHost(gauge);
        System.out.println("consumer handle got report from "+gauge.toString());
        //GaugeControl theGauge = new RMIGaugeHandle(host);
        RMIGauge theGauge = new RMIGauge(gauge);
        gaugeConsumer.onReportValue(theGauge, valueName, propertyName, value);
    }
    
    /** Called when multiple values are reported
     * @param gauge The gauge reporting the values
     * @param values The values
     */    
    public void onReportMultipleValues(GaugeControl gauge, GaugeValueVector values) throws java.rmi.RemoteException
    {
        gaugeConsumer.onReportMultipleValues(gauge, values);
    }
    
    /** Called when a configured event is reported
     * @param theGaugeID The GaugeID of the gauge reporting the event
     * @param configParams The configuration parameters for this gauge.     
     */    
    public void onReportConfigured(GaugeID gauge, StringPairVector configParams) throws java.rmi.RemoteException
    {
        String host = gaugeBus.getGaugeHost(gauge);
        GaugeControl theGauge = new RMIGaugeHandle(host);       
        gaugeConsumer.onReportConfigured(theGauge, configParams);
    }
    
    /** Called when a deleted event is reported
     * @param gauge The GaugeID of the gauge reporting the event
     */    
    public void onReportDeleted(GaugeID gauge) throws java.rmi.RemoteException
    {
        //String host = gaugeBus.getGaugeHost(gauge);
        
        //System.err.println(host);

        GaugeControl theGauge = new RMIGauge(gauge);
        gaugeConsumer.onReportDeleted(theGauge);
    }
    
    /** Called when a created event is reported
     * @param gauge The GaugeID of the gauge reporting the event
     */    
    public void onReportCreated(GaugeID gauge) throws java.rmi.RemoteException
    {
        RMIGauge g = new RMIGauge(gauge);
        gaugeConsumer.onReportCreated(g);
    }
        
}
