/**
 * $Header: D:/Projects/Repository/GaugeAPI/edu/cmu/cs/able/gaugeInfrastructure/RMI/RMIGaugeReportingBus.java,v 1.3 2002/01/31 16:39:05 schmerl Exp $
 * $Log: RMIGaugeReportingBus.java,v $
 * Revision 1.3  2002/01/31 16:39:05  schmerl
 * Added CVS header information
 *
 */

package edu.cmu.cs.able.gaugeInfrastructure.RMI;

import java.util.Vector;
import java.util.Enumeration;
import java.rmi.*;

import edu.cmu.cs.able.gaugeInfrastructure.*;
import edu.cmu.cs.able.gaugeInfrastructure.Events.*;
import edu.cmu.cs.able.gaugeInfrastructure.util.*;
import edu.cmu.cs.able.gaugeInfrastructure.RMI.Events.*;
/**
  * RMIGaugeReportingBus is bus used to by the gauges, gauge managers
 * and gauge consumers to report value or broadcast events.
 * @author      Hong Yan
 * @author      Bradley Schmerl
 * @version     1.0
 * @since       JDK1.3.1
 */
public class RMIGaugeReportingBus implements GaugeReportingBus, java.io.Serializable
{
    private RMIEventBusHandle theRMIEventBusHandle;
    
    /** Creates new RMIGaugeReportingBus */
    public RMIGaugeReportingBus(String host) throws java.rmi.RemoteException
    {
        super();
        theRMIEventBusHandle = (RMIEventBusHandle)connectTo(host);
    }

    public boolean reportValue(GaugeID gauge, String valueName, String propertyName, String value)
    {
        try {
            theRMIEventBusHandle.reportValue(gauge, valueName, propertyName, value);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
        return true;
    }
    
    
    public boolean reportMultipleValues(GaugeID gauge, GaugeValueVector values)
    {
        try {
            theRMIEventBusHandle.reportMultipleValues(gauge, values);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
        return true;
    }
    
    
    public boolean reportConfigured(GaugeID gauge, StringPairVector configParams)
    {
        try {
            theRMIEventBusHandle.reportConfigured(gauge, configParams);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
        return true;
    }
    
    
    public boolean reportDeleted(GaugeID gauge)
    {
        try {
            theRMIEventBusHandle.reportDeleted(gauge);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
        return true;
    }
        
    public boolean reportCreated(GaugeID gauge)
    {
        try {
            theRMIEventBusHandle.reportCreated(gauge);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
        return true;
    }
    
    public void subscribeToGaugeEvent(GaugeEvent event, Subscriber subscriber)
    {
        try {
            theRMIEventBusHandle.subscribeToGaugeEvent(event, subscriber);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
    }
    
    public void unsubscribeToGaugeEvent(GaugeEvent event, Subscriber subscriber)
    {
        try {
            theRMIEventBusHandle.unsubscribeToGaugeEvent(event, subscriber);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
    }

    private java.rmi.Remote connectTo(String host) {
        try {
            RMIEventBusHandle ebh = (RMIEventBusHandle)Naming.lookup("rmi://"+host+"/RMIEventBus");
            return ebh;
        }
        catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }
    
    public String getGaugeHost(GaugeID gid)
    {
        try {
            return theRMIEventBusHandle.getGaugeHost(gid);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
        return null;
    }
    
    public void subscribeInterest(String gaugeConsumerUID, GaugeID theGaugeID, GaugeEventType gaugeEvent)
    {
        try {
            theRMIEventBusHandle.subscribeInterest(gaugeConsumerUID, theGaugeID, gaugeEvent);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
    }
    
    public void registerGauge(GaugeID theGaugeID, StringPairVector setupParams, String host)
    {
        try {
            System.out.println("register gauge");           
            theRMIEventBusHandle.registerGauge(theGaugeID, setupParams, host);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
    }
    
    public void registerGaugeMgr(String gaugeMgrUID, String gaugeMgrType, String gaugeMgrHost) {
        try {
            theRMIEventBusHandle.registerGaugeMgr(gaugeMgrHost, gaugeMgrUID, gaugeMgrType);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
    }
    
    public void configureGauge(GaugeID theGaugeID, StringPairVector configParams)
    {
        try {
            theRMIEventBusHandle.configureGauge(theGaugeID, configParams);
            System.out.println("RMIEventBus.configureGauge"+theGaugeID.toString()+configParams.toString());
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
    }

    public void createGauge(GaugeID theGaugeID, StringPairVector setupParams, StringPairVector mappings)
    {
        try {
            theRMIEventBusHandle.createGauge(theGaugeID, setupParams, mappings);
            System.out.println("RMIEventBus.createGauge"+theGaugeID.toString());
        }
        catch (RemoteException re) {
            //re.printStackTrace();
        }
    }

    public void deleteGauge(GaugeID theGaugeID)
    {
        try {
            theRMIEventBusHandle.deleteGauge(theGaugeID);
            System.out.println("RMIEventBus.deleteGauge"+theGaugeID.toString());
        }
        catch (RemoteException re) {
            //re.printStackTrace();
        }
    }
        
    public void registerGaugeConsumer(String gaugeConsumerUID, int port) throws java.rmi.RemoteException        {
        try {
            String thePort = Integer.toString(port);
            theRMIEventBusHandle.registerGaugeConsumer(gaugeConsumerUID, Global.getHost()+":"+thePort);
        }
        catch (RemoteException re) {
            re.printStackTrace();
        }
    }

    public String getGaugeMgr(String gaugeMgrType)
    {
        String res = "";
        try {
            res = theRMIEventBusHandle.getGaugeMgr(gaugeMgrType);
            System.out.println("RMIEventBus.getGaugeMgr"+res);
        }
        catch (RemoteException re) {
            //re.printStackTrace();
        }
        return res;
    }
    
    public void queryMetaInfo(String gaugeType, StringPairVector configParamsMeta, StringPairVector valuesMeta)
{
        try {
            theRMIEventBusHandle.queryConfigMetaInfo(gaugeType).copyInto(configParamsMeta);
theRMIEventBusHandle.queryValueMetaInfo(gaugeType).copyInto(valuesMeta);
        }
        catch (RemoteException re) {
            //re.printStackTrace();
        }
    }
}
